% Auto-generated chapter 3 for abudawud
% Hadiths in this chapter: 37

\hadithdefcmd{abudawud}{1161}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدِ بْنِ ثَابِتٍ الْمَرْوَزِيُّ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عَبَّادِ بْنِ تَمِيمٍ، عَنْ عَمِّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَرَجَ بِالنَّاسِ لِيَسْتَسْقِيَ فَصَلَّى بِهِمْ رَكْعَتَيْنِ جَهَرَ بِالْقِرَاءَةِ فِيهِمَا وَحَوَّلَ رِدَاءَهُ وَرَفَعَ يَدَيْهِ فَدَعَا وَاسْتَسْقَى وَاسْتَقْبَلَ الْقِبْلَةَ ‏.‏\hadithno{1161}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (1023) Sahih Muslim (894)}\hadithtrans{Abbad b. Tamim (al-Muzini) reported on the authority of his uncle:The Messenger of Allah (ﷺ) took the people out (to the place of prayer) and prayed for rain. He led them in two rak'ahs of prayer in the course of which he recited from the Qur'an in a loud voice. He turned around his cloak and raised his hands, prayed for rain and faced the qiblah}}
\hadithdefcmd{abudawud}{1162}{حَدَّثَنَا ابْنُ السَّرْحِ، وَسُلَيْمَانُ بْنُ دَاوُدَ، قَالاَ أَخْبَرَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي ابْنُ أَبِي ذِئْبٍ، وَيُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي عَبَّادُ بْنُ تَمِيمٍ الْمَازِنِيُّ، أَنَّهُ سَمِعَ عَمَّهُ، - وَكَانَ مِنْ أَصْحَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم يَقُولُ خَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمًا يَسْتَسْقِي فَحَوَّلَ إِلَى النَّاسِ ظَهْرَهُ يَدْعُو اللَّهَ عَزَّ وَجَلَّ - قَالَ سُلَيْمَانُ بْنُ دَاوُدَ وَاسْتَقْبَلَ الْقِبْلَةَ وَحَوَّلَ رِدَاءَهُ ثُمَّ صَلَّى رَكْعَتَيْنِ - قَالَ ابْنُ أَبِي ذِئْبٍ - وَقَرَأَ فِيهِمَا زَادَ ابْنُ السَّرْحِ يُرِيدُ الْجَهْرَ ‏.‏\hadithno{1162}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1023) Sahih Muslim (894)}\hadithtrans{Abbad b. Tamim al Mazini said on the authority of his uncle (Abd Allah b. Zaid b Asim) who was a Companion of the Messenger of Allah (ﷺ):One day the Messenger of Allah (ﷺ) went out to make supplication for rain. He turned his back towards the people praying to Allah, the Exalted. The narrator Sulaiman b. Dawud said: He faced the qiblah and turned around his cloak and then offered two rak'ahs of prayer. The narrator Ibn Abi Dhi'b said: He recited from the Qur'an in both of them. The version of Ibn al-Sarh adds: By it he means in a loud voice}}
\hadithdefcmd{abudawud}{1163}{حَدَّثَنَا مُحَمَّدُ بْنُ عَوْفٍ، قَالَ قَرَأْتُ فِي كِتَابِ عَمْرِو بْنِ الْحَارِثِ - يَعْنِي الْحِمْصِيَّ - عَنْ عَبْدِ اللَّهِ بْنِ سَالِمٍ، عَنِ الزُّبَيْدِيِّ، عَنْ مُحَمَّدِ بْنِ مُسْلِمٍ، بِهَذَا الْحَدِيثِ بِإِسْنَادِهِ لَمْ يَذْكُرِ الصَّلاَةَ قَالَ وَحَوَّلَ رِدَاءَهُ فَجَعَلَ عِطَافَهُ الأَيْمَنَ عَلَى عَاتِقِهِ الأَيْسَرِ وَجَعَلَ عِطَافَهُ الأَيْسَرَ عَلَى عَاتِقِهِ الأَيْمَنِ ثُمَّ دَعَا اللَّهَ عَزَّ وَجَلَّ ‏.‏\hadithno{1163}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{The above-mentioned tradition has also been transmitted by Muhammad b. Muslim through a different chain of narrators. But there is no mention of prayer in this version. The version adds:"He turned around his cloak, putting its right side on his left shoulder and its left side on his right shoulder. Thereafter he made supplication to Allah}}
\hadithdefcmd{abudawud}{1164}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، عَنْ عُمَارَةَ بْنِ غَزِيَّةَ، عَنْ عَبَّادِ بْنِ تَمِيمٍ، أَنَّ عَبْدَ اللَّهِ بْنَ زَيْدٍ، قَالَ اسْتَسْقَى رَسُولُ اللَّهِ صلى الله عليه وسلم وَعَلَيْهِ خَمِيصَةٌ لَهُ سَوْدَاءُ فَأَرَادَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يَأْخُذَ بِأَسْفَلِهَا فَيَجْعَلَهُ أَعْلاَهَا فَلَمَّا ثَقُلَتْ قَلَبَهَا عَلَى عَاتِقِهِ ‏.‏\hadithno{1164}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abd Allah b. Zaid said:The Messenger of Allah (pbuh)prayed for rain wearing a black robe with ornamented border. The Messenger of Allah (pbuh)wanted to reverse it from bottom to top by holding the bottom. But when it was too heavy he turned it round on his shoulders}}
\hadithdefcmd{abudawud}{1165}{حَدَّثَنَا النُّفَيْلِيُّ، وَعُثْمَانُ بْنُ أَبِي شَيْبَةَ، نَحْوَهُ قَالاَ حَدَّثَنَا حَاتِمُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا هِشَامُ بْنُ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ كِنَانَةَ، قَالَ أَخْبَرَنِي أَبِي قَالَ، أَرْسَلَنِي الْوَلِيدُ بْنُ عُتْبَةَ - قَالَ عُثْمَانُ ابْنُ عُقْبَةَ وَكَانَ أَمِيرَ الْمَدِينَةِ - إِلَى ابْنِ عَبَّاسٍ أَسْأَلُهُ عَنْ صَلاَةِ، رَسُولِ اللَّهِ صلى الله عليه وسلم فِي الاِسْتِسْقَاءِ فَقَالَ خَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم مُتَبَذِّلاً مُتَوَاضِعًا مُتَضَرِّعًا حَتَّى أَتَى الْمُصَلَّى - زَادَ عُثْمَانُ فَرَقِيَ عَلَى الْمِنْبَرِ ثُمَّ اتَّفَقَا - وَلَمْ يَخْطُبْ خُطَبَكُمْ هَذِهِ وَلَكِنْ لَمْ يَزَلْ فِي الدُّعَاءِ وَالتَّضَرُّعِ وَالتَّكْبِيرِ ثُمَّ صَلَّى رَكْعَتَيْنِ كَمَا يُصَلِّي فِي الْعِيدِ ‏.‏ قَالَ أَبُو دَاوُدَ وَالإِخْبَارُ لِلنُّفَيْلِيِّ وَالصَّوَابُ ابْنُ عُتْبَةَ ‏.‏\hadithno{1165}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Abbas: Ishaq ibn Abdullah ibn Kinanah reported: Al-Walid ibn Utbah or (according to the version of Uthman) al-Walid ibn Uqbah, the then governor of Medina, sent me to Ibn Abbas to ask him about the prayer for rain offered by the Messenger of Allah (ﷺ). He said: The Messenger of Allah (ﷺ) went out wearing old clothes in a humble and lowly manner until he reached the place of prayer. He then ascended the pulpit, but he did not deliver the sermon as you deliver (usually). He remained engaged in making supplication, showing humbleness (to Allah) and uttering the takbir (Allah is most great). He then offered two rak'ahs of prayer as done on the 'Id (festival). Abu Dawud said: This is the version of al-Nufail. What is correct is Ibn Utbah's}}
\hadithdefcmd{abudawud}{1166}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، حَدَّثَنَا سُلَيْمَانُ، - يَعْنِي ابْنَ بِلاَلٍ - عَنْ يَحْيَى، عَنْ أَبِي بَكْرِ بْنِ مُحَمَّدٍ، عَنْ عَبَّادِ بْنِ تَمِيمٍ، أَنَّ عَبْدَ اللَّهِ بْنَ زَيْدٍ، أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَرَجَ إِلَى الْمُصَلَّى يَسْتَسْقِي وَأَنَّهُ لَمَّا أَرَادَ أَنْ يَدْعُوَ اسْتَقْبَلَ الْقِبْلَةَ ثُمَّ حَوَّلَ رِدَاءَهُ ‏.‏\hadithno{1166}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1023) Sahih Muslim (894)}\hadithtrans{Abd Allah b. Zaid said:The Messenger of Allah (pbuh)went out to the place of prayer to pray for rain. When he wanted to make supplication, he faced the qiblah and turned around his cloak}}
\hadithdefcmd{abudawud}{1167}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، أَنَّهُ سَمِعَ عَبَّادَ بْنَ تَمِيمٍ، يَقُولُ سَمِعْتُ عَبْدَ اللَّهِ بْنَ زَيْدٍ الْمَازِنِيَّ، يَقُولُ خَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى الْمُصَلَّى فَاسْتَسْقَى وَحَوَّلَ رِدَاءَهُ حِينَ اسْتَقْبَلَ الْقِبْلَةَ ‏.‏\hadithno{1167}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1023) Sahih Muslim (894)}\hadithtrans{Narrated Abd Allah b. Zaid al Mazini:Abd Allah b. Zaid al Mazini said: The Messenger of Allah (pbuh) went out to the place of prayer and made supplication or rain, and turned around his cloak when the faced the qiblah}}
\hadithdefcmd{abudawud}{1168}{حَدَّثَنَا مُحَمَّدُ بْنُ سَلَمَةَ الْمُرَادِيُّ، أَخْبَرَنَا ابْنُ وَهْبٍ، عَنْ حَيْوَةَ، وَعُمَرَ بْنِ مَالِكٍ، عَنِ ابْنِ الْهَادِ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ، عَنْ عُمَيْرٍ، مَوْلَى بَنِي آبِي اللَّحْمِ أَنَّهُ رَأَى النَّبِيَّ صلى الله عليه وسلم يَسْتَسْقِي عِنْدَ أَحْجَارِ الزَّيْتِ قَرِيبًا مِنَ الزَّوْرَاءِ قَائِمًا يَدْعُو يَسْتَسْقِي رَافِعًا يَدَيْهِ قِبَلَ وَجْهِهِ لاَ يُجَاوِزُ بِهِمَا رَأْسَهُ ‏.‏\hadithno{1168}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Umayr, the client of AbulLahm: Umayr saw the Prophet (ﷺ) praying for rain at Ahjar az-Zayt near az-Zawra', standing, making supplication, praying for rain and raising his hands in front of his face, but not lifting them above his head}}
\hadithdefcmd{abudawud}{1169}{حَدَّثَنَا ابْنُ أَبِي خَلَفٍ، حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ، حَدَّثَنَا مِسْعَرٌ، عَنْ يَزِيدَ الْفَقِيرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ أَتَتِ النَّبِيَّ صلى الله عليه وسلم بَوَاكِي فَقَالَ ‏ "‏ اللَّهُمَّ اسْقِنَا غَيْثًا مُغِيثًا مَرِيئًا مَرِيعاً نَافِعًا غَيْرَ ضَارٍّ عَاجِلاً غَيْرَ آجِلٍ ‏"‏ ‏.‏ قَالَ فَأَطْبَقَتْ عَلَيْهِمُ السَّمَاءُ ‏.‏\hadithno{1169}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Jabir ibn Abdullah: The people came to the Prophet (ﷺ) weeping (due to drought). He said (making supplication): O Allah! give us rain which will replenish us, abundant, fertilising and profitable, not injurious, granting it now without delay. He (the narrator) said: Thereupon the sky became overcast}}
\hadithdefcmd{abudawud}{1170}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، أَخْبَرَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ لاَ يَرْفَعُ يَدَيْهِ فِي شَىْءٍ مِنَ الدُّعَاءِ إِلاَّ فِي الاِسْتِسْقَاءِ فَإِنَّهُ كَانَ يَرْفَعُ يَدَيْهِ حَتَّى يُرَى بَيَاضُ إِبْطَيْهِ ‏.‏\hadithno{1170}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (3565) Sahih Muslim (896)}\hadithtrans{Narrated Anas:The Prophet (peace be upon him) was not accustomed to raise his hands in any supplication he made except when praying for rain. He would then raise them high enough so much so that the whiteness of his armpits was visible}}
\hadithdefcmd{abudawud}{1171}{حَدَّثَنَا الْحَسَنُ بْنُ مُحَمَّدٍ الزَّعْفَرَانِيُّ، حَدَّثَنَا عَفَّانُ، حَدَّثَنَا حَمَّادٌ، أَخْبَرَنَا ثَابِتٌ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَسْتَسْقِي هَكَذَا يَعْنِي وَمَدَّ يَدَيْهِ وَجَعَلَ بُطُونَهُمَا مِمَّا يَلِي الأَرْضَ حَتَّى رَأَيْتُ بَيَاضَ إِبْطَيْهِ ‏.‏\hadithno{1171}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (896)}\hadithtrans{Narrated Anas:The Prophet (ﷺ) used to make supplication for rain in this manner. he spread his hands keeping the inner side (of hands) towards the earth, so I witnessed the whiteness of his armpits}}
\hadithdefcmd{abudawud}{1172}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ رَبِّهِ بْنِ سَعِيدٍ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ، أَخْبَرَنِي مَنْ، رَأَى النَّبِيَّ صلى الله عليه وسلم يَدْعُو عِنْدَ أَحْجَارِ الزَّيْتِ بَاسِطًا كَفَّيْهِ ‏.‏\hadithno{1172}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Muhammad b. Ibrahim:A man who witnessed the Prophet (ﷺ) reported to me that he saw the Prophet (ﷺ) praying at Ahjar al-Zait spreading his hands}}
\hadithdefcmd{abudawud}{1173}{حَدَّثَنَا هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، حَدَّثَنَا خَالِدُ بْنُ نِزَارٍ، حَدَّثَنِي الْقَاسِمُ بْنُ مَبْرُورٍ، عَنْ يُونُسَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ شَكَى النَّاسُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم قُحُوطَ الْمَطَرِ فَأَمَرَ بِمِنْبَرٍ فَوُضِعَ لَهُ فِي الْمُصَلَّى وَوَعَدَ النَّاسَ يَوْمًا يَخْرُجُونَ فِيهِ قَالَتْ عَائِشَةُ فَخَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم حِينَ بَدَا حَاجِبُ الشَّمْسِ فَقَعَدَ عَلَى الْمِنْبَرِ فَكَبَّرَ صلى الله عليه وسلم وَحَمِدَ اللَّهَ عَزَّ وَجَلَّ ثُمَّ قَالَ ‏"‏ إِنَّكُمْ شَكَوْتُمْ جَدْبَ دِيَارِكُمْ وَاسْتِئْخَارَ الْمَطَرِ عَنْ إِبَّانِ زَمَانِهِ عَنْكُمْ وَقَدْ أَمَرَكُمُ اللَّهُ عَزَّ وَجَلَّ أَنْ تَدْعُوهُ وَوَعَدَكُمْ أَنْ يَسْتَجِيبَ لَكُمْ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ ‏\{‏ الْحَمْدُ لِلَّهِ رَبِّ الْعَالَمِينَ * الرَّحْمَنِ الرَّحِيمِ * مَلِكِ يَوْمِ الدِّينِ ‏\}‏ لاَ إِلَهَ إِلاَّ اللَّهُ يَفْعَلُ مَا يُرِيدُ اللَّهُمَّ أَنْتَ اللَّهُ لاَ إِلَهَ إِلاَّ أَنْتَ الْغَنِيُّ وَنَحْنُ الْفُقَرَاءُ أَنْزِلْ عَلَيْنَا الْغَيْثَ وَاجْعَلْ مَا أَنْزَلْتَ لَنَا قُوَّةً وَبَلاَغًا إِلَى حِينٍ ‏"‏ ‏.‏ ثُمَّ رَفَعَ يَدَيْهِ فَلَمْ يَزَلْ فِي الرَّفْعِ حَتَّى بَدَا بَيَاضُ إِبْطَيْهِ ثُمَّ حَوَّلَ عَلَى النَّاسِ ظَهْرَهُ وَقَلَّبَ أَوْ حَوَّلَ رِدَاءَهُ وَهُوَ رَافِعٌ يَدَيْهِ ثُمَّ أَقْبَلَ عَلَى النَّاسِ وَنَزَلَ فَصَلَّى رَكْعَتَيْنِ فَأَنْشَأَ اللَّهُ سَحَابَةً فَرَعَدَتْ وَبَرَقَتْ ثُمَّ أَمْطَرَتْ بِإِذْنِ اللَّهِ فَلَمْ يَأْتِ مَسْجِدَهُ حَتَّى سَالَتِ السُّيُولُ فَلَمَّا رَأَى سُرْعَتَهُمْ إِلَى الْكِنِّ ضَحِكَ صلى الله عليه وسلم حَتَّى بَدَتْ نَوَاجِذُهُ فَقَالَ ‏"‏ أَشْهَدُ أَنَّ اللَّهَ عَلَى كُلِّ شَىْءٍ قَدِيرٌ وَأَنِّي عَبْدُ اللَّهِ وَرَسُولُهُ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَهَذَا حَدِيثٌ غَرِيبٌ إِسْنَادُهُ جَيِّدٌ أَهْلُ الْمَدِينَةِ يَقْرَءُونَ ‏\{‏ مَلِكِ يَوْمِ الدِّينِ ‏\}‏ وَإِنَّ هَذَا الْحَدِيثَ حُجَّةٌ لَهُمْ ‏.‏\hadithno{1173}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Aisha, Ummul Mu'minin: The people complained to the Messenger of Allah (ﷺ) of the lack of rain, so he gave an order for a pulpit. It was then set up for him in the place of prayer. He fixed a day for the people on which they should come out. Aisha said: The Messenger of Allah (ﷺ), when the rim of the sun appeared, sat down on the pulpit, and having pronounced the greatness of Allah and expressed His praise, he said: You have complained of drought in your homes, and of the delay in receiving rain at the beginning of its season. Allah has ordered you to supplicate Him has and promised that He will answer your prayer. Then he said: Praise be to Allah, the Lord of the Universe, the Compassionate, the Merciful, the Master of the Day of Judgment. There is no god but Allah Who does what He wishes. O Allah, Thou art Allah, there is no deity but Thou, the Rich, while we are the poor. Send down the rain upon us and make what Thou sendest down a strength and satisfaction for a time. He then raised his hands, and kept raising them till the whiteness under his armpits was visible. He then turned his back to the people and inverted or turned round his cloak while keeping his hands aloft. He then faced the people, descended and prayed two rak'ahs. Allah then produced a cloud, and the storm of thunder and lightning came on. Then the rain fell by Allah's permission, and before he reached his mosque streams were flowing. When he saw the speed with which the people were seeking shelter, he (ﷺ) laughed till his back teeth were visible. Then he said: I testify that Allah is Omnipotent and that I am Allah's servant and apostle. Abu Dawud said: This is a ghraib (rate) tradition, but its chain is sound. The people of Medina recite "maliki" (instead of maaliki) yawm al-din" (the master of the Day of Judgement). But this tradition (in which the word maalik occurs) is an evidence for them}}
\hadithdefcmd{abudawud}{1174}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ عَبْدِ الْعَزِيزِ بْنِ صُهَيْبٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، وَيُونُسُ بْنُ عُبَيْدٍ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، قَالَ أَصَابَ أَهْلَ الْمَدِينَةِ قَحْطٌ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَبَيْنَمَا هُوَ يَخْطُبُنَا يَوْمَ جُمُعَةٍ إِذْ قَامَ رَجُلٌ فَقَالَ يَا رَسُولَ اللَّهِ هَلَكَ الْكُرَاعُ هَلَكَ الشَّاءُ فَادْعُ اللَّهَ أَنْ يَسْقِيَنَا فَمَدَّ يَدَيْهِ وَدَعَا قَالَ أَنَسٌ وَإِنَّ السَّمَاءَ لَمِثْلُ الزُّجَاجَةِ فَهَاجَتْ رِيحٌ ثُمَّ أَنْشَأَتْ سَحَابَةً ثُمَّ اجْتَمَعَتْ ثُمَّ أَرْسَلَتِ السَّمَاءُ عَزَالِيَهَا فَخَرَجْنَا نَخُوضُ الْمَاءَ حَتَّى أَتَيْنَا مَنَازِلَنَا فَلَمْ يَزَلِ الْمَطَرُ إِلَى الْجُمُعَةِ الأُخْرَى فَقَامَ إِلَيْهِ ذَلِكَ الرَّجُلُ أَوْ غَيْرُهُ فَقَالَ يَا رَسُولَ اللَّهِ تَهَدَّمَتِ الْبُيُوتُ فَادْعُ اللَّهَ أَنْ يَحْبِسَهُ فَتَبَسَّمَ رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ قَالَ ‏ "‏ حَوَالَيْنَا وَلاَ عَلَيْنَا ‏"‏ ‏.‏ فَنَظَرْتُ إِلَى السَّحَابِ يَتَصَدَّعُ حَوْلَ الْمَدِينَةِ كَأَنَّهُ إِكْلِيلٌ ‏.‏\hadithno{1174}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (932)}\hadithtrans{Narrated Anas ibn Malik: The people of Medina had a drought during the time of the Prophet (ﷺ). While he was preaching on a Friday, a man stood up and said: Messenger of Allah, the horses have perished, the goats have perished, pray to Allah to give us water. He spread his hands and prayed. Anas said: The sky was like a mirror (there was no cloud). Then the wind rose; a cloud appeared (in the sky) and it spread : the sky poured down the water. We came out (from the mosque after the prayer) passing through the water till we reached our homes. The rain continued till the following Friday. The same or some other person stood up and said: Messenger of Allah, the houses have been demolished, pray to Allah to stop it. The Messenger of Allah (ﷺ) smiled and said: (O Allah), the rain may fall around us but not upon us. Then I looked at the cloud which dispersed around Medina just like a crown}}
\hadithdefcmd{abudawud}{1175}{حَدَّثَنَا عِيسَى بْنُ حَمَّادٍ، أَخْبَرَنَا اللَّيْثُ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ شَرِيكِ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي نَمِرٍ، عَنْ أَنَسٍ، أَنَّهُ سَمِعَهُ يَقُولُ فَذَكَرَ نَحْوَ حَدِيثِ عَبْدِ الْعَزِيزِ قَالَ فَرَفَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَدَيْهِ بِحِذَاءِ وَجْهِهِ فَقَالَ ‏ "‏ اللَّهُمَّ اسْقِنَا ‏"‏ ‏.‏ وَسَاقَ نَحْوَهُ ‏.‏\hadithno{1175}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1013) Sahih Muslim (897)}\hadithtrans{Narrated The above mentioned tradition has been narrated by Anas through a different chain of transmitters:The Messenger of Allah (ﷺ) raised his hands in front of his face and said: O Allah! Give us water. the narrator then reported then reported the tradition like the former}}
\hadithdefcmd{abudawud}{1176}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَقُولُ ح وَحَدَّثَنَا سَهْلُ بْنُ صَالِحٍ حَدَّثَنَا عَلِيُّ بْنُ قَادِمٍ أَخْبَرَنَا سُفْيَانُ عَنْ يَحْيَى بْنِ سَعِيدٍ عَنْ عَمْرِو بْنِ شُعَيْبٍ عَنْ أَبِيهِ عَنْ جَدِّهِ قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا اسْتَسْقَى قَالَ ‏ "‏ اللَّهُمَّ اسْقِ عِبَادَكَ وَبَهَائِمَكَ وَانْشُرْ رَحْمَتَكَ وَأَحْىِ بَلَدَكَ الْمَيِّتَ ‏"‏ ‏.‏ هَذَا لَفْظُ حَدِيثِ مَالِكٍ ‏.‏\hadithno{1176}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated 'Amr b. Suh'aib: On his father's authority, quoted his grandfather as saying: When the Messenger of Allah (ﷺ) prayed for rain, he said: O Allah! Provide water for Your servants and Your cattle, display Your mercy and give life to Your dead land. This is the wording of Malik}}
\hadithdefcmd{abudawud}{1177}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، عَنِ ابْنِ جُرَيْجٍ، عَنْ عَطَاءٍ، عَنْ عُبَيْدِ بْنِ عُمَيْرٍ، أَخْبَرَنِي مَنْ، أُصَدِّقُ وَظَنَنْتُ أَنَّهُ يُرِيدُ عَائِشَةَ قَالَ كُسِفَتِ الشَّمْسُ عَلَى عَهْدِ النَّبِيِّ صلى الله عليه وسلم فَقَامَ النَّبِيُّ صلى الله عليه وسلم قِيَامًا شَدِيدًا يَقُومُ بِالنَّاسِ ثُمَّ يَرْكَعُ ثُمَّ يَقُومُ ثُمَّ يَرْكَعُ ثُمَّ يَقُومُ ثُمَّ يَرْكَعُ فَرَكَعَ رَكْعَتَيْنِ فِي كُلِّ رَكْعَةٍ ثَلاَثُ رَكَعَاتٍ يَرْكَعُ الثَّالِثَةَ ثُمَّ يَسْجُدُ حَتَّى إِنَّ رِجَالاً يَوْمَئِذٍ لَيُغْشَى عَلَيْهِمْ مِمَّا قَامَ بِهِمْ حَتَّى إِنَّ سِجَالَ الْمَاءِ لَتُصَبُّ عَلَيْهِمْ يَقُولُ إِذَا رَكَعَ ‏"‏ اللَّهُ أَكْبَرُ ‏"‏ ‏.‏ وَإِذَا رَفَعَ ‏"‏ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ ‏"‏ ‏.‏ حَتَّى تَجَلَّتِ الشَّمْسُ ثُمَّ قَالَ ‏"‏ إِنَّ الشَّمْسَ وَالْقَمَرَ لاَ يَنْكَسِفَانِ لِمَوْتِ أَحَدٍ وَلاَ لِحَيَاتِهِ وَلَكِنَّهُمَا آيَتَانِ مِنْ آيَاتِ اللَّهِ عَزَّ وَجَلَّ يُخَوِّفُ بِهِمَا عِبَادَهُ فَإِذَا كُسِفَا فَافْزَعُوا إِلَى الصَّلاَةِ ‏"‏ ‏.‏\hadithno{1177}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Shadh; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Sahih Muslim (901)}\hadithtrans{Narrated A'ishah (May Allah be pleased with her):There was an eclipse of the sun in the time of the Prophet (ﷺ). The Prophet stood for a long time, accompanied by the people. He then bowed, then raised his head, then he bowed and then he raised his head, and again he bowed and prayed two rak'ahs of prayer. In each rak'ah he bowed three times. After bowing for the third time he prostrated himself. He stood for such a long time that some people became unconscious on that occasion and buckets of water had to be poured on them. When he bowed, he said, Allah is most great; and when he raised his head, he said, Allah listens to him who praises Him, till the sun became bright. then he said: The sun and the moon are not eclipsed on account of anyone's death or on account of anyone's birth, but they are two of Allah's signs, He produces dread in His servants by means of them. When they are eclipsed, hasten to prayer}}
\hadithdefcmd{abudawud}{1178}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا يَحْيَى، عَنْ عَبْدِ الْمَلِكِ، حَدَّثَنِي عَطَاءٌ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ كُسِفَتِ الشَّمْسُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَكَانَ ذَلِكَ فِي الْيَوْمِ الَّذِي مَاتَ فِيهِ إِبْرَاهِيمُ ابْنُ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ النَّاسُ إِنَّمَا كُسِفَتْ لِمَوْتِ إِبْرَاهِيمَ ابْنِهِ صلى الله عليه وسلم فَقَامَ النَّبِيُّ صلى الله عليه وسلم فَصَلَّى بِالنَّاسِ سِتَّ رَكَعَاتٍ فِي أَرْبَعِ سَجَدَاتٍ كَبَّرَ ثُمَّ قَرَأَ فَأَطَالَ الْقِرَاءَةَ ثُمَّ رَكَعَ نَحْوًا مِمَّا قَامَ ثُمَّ رَفَعَ رَأْسَهُ فَقَرَأَ دُونَ الْقِرَاءَةِ الأُولَى ثُمَّ رَكَعَ نَحْوًا مِمَّا قَامَ ثُمَّ رَفَعَ رَأْسَهُ فَقَرَأَ الْقِرَاءَةَ الثَّالِثَةَ دُونَ الْقِرَاءَةِ الثَّانِيَةِ ثُمَّ رَكَعَ نَحْوًا مِمَّا قَامَ ثُمَّ رَفَعَ رَأْسَهُ فَانْحَدَرَ لِلسُّجُودِ فَسَجَدَ سَجْدَتَيْنِ ثُمَّ قَامَ فَرَكَعَ ثَلاَثَ رَكَعَاتٍ قَبْلَ أَنْ يَسْجُدَ لَيْسَ فِيهَا رَكْعَةٌ إِلاَّ الَّتِي قَبْلَهَا أَطْوَلُ مِنَ الَّتِي بَعْدَهَا إِلاَّ أَنَّ رُكُوعَهُ نَحْوٌ مِنْ قِيَامِهِ قَالَ ثُمَّ تَأَخَّرَ فِي صَلاَتِهِ فَتَأَخَّرَتِ الصُّفُوفُ مَعَهُ ثُمَّ تَقَدَّمَ فَقَامَ فِي مَقَامِهِ وَتَقَدَّمَتِ الصُّفُوفُ فَقَضَى الصَّلاَةَ وَقَدْ طَلَعَتِ الشَّمْسُ فَقَالَ ‏ "‏ يَا أَيُّهَا النَّاسُ إِنَّ الشَّمْسَ وَالْقَمَرَ آيَتَانِ مِنْ آيَاتِ اللَّهِ عَزَّ وَجَلَّ لاَ يَنْكَسِفَانِ لِمَوْتِ بَشَرٍ فَإِذَا رَأَيْتُمْ شَيْئًا مِنْ ذَلِكَ فَصَلُّوا حَتَّى تَنْجَلِيَ ‏"‏ ‏.‏ وَسَاقَ بَقِيَّةَ الْحَدِيثِ ‏.‏\hadithno{1178}\hadithgrade{Al-Albani: Shadh; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (904)}\hadithtrans{Narrated Jabir b. Abd Allah:There was an eclipse of the sun in the time of the Messenger of Allah (ﷺ) had died. The people began to to say that there was an eclipse on account of the death of Ibrahim. The Prophet (ﷺ) stood up and led the people in prayer performing six bowings and four prostrations. he said: Allah is most great, and then recited from the Qur'an and prolonged the recitation. He then bowed nearly as long as he stood. He then raised his head and recited from the Qur'an but it was less than the first (recitation). He then bowed nearly as long as he stood. He then raised his head and then recited from the Quran for the third time, but it was less than the second recitation. He then bowed nearly as long as he stood. he then raised his head and then recited from the Qur'an for the third time, but it was less than the second recitation. he then bowed nearly as long as he stood. Then he raised his head and went down for prostration. he made two prostrations. He then stood and made three bowings before prostrating himself, the preceding bowing being more lengthy than the following, but he bowed nearly as long as he stood. He then stepped back during the prayer and the rows (of the people) too stepped back along with him. Then he stepped forward and stood in his place, and the rows too stepped forward. he then finished the prayer and the sun had become bright. He said: O people, the sun and the moon are two of Allah's signs; they are not eclipsed on account of a man's death. So when you see anything of that nature, offer prayer until the sun becomes bright. The narrator then narrated the rest of the tradition}}
\hadithdefcmd{abudawud}{1179}{حَدَّثَنَا مُؤَمَّلُ بْنُ هِشَامٍ، حَدَّثَنَا إِسْمَاعِيلُ، عَنْ هِشَامٍ، حَدَّثَنَا أَبُو الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ كُسِفَتِ الشَّمْسُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي يَوْمٍ شَدِيدِ الْحَرِّ فَصَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم بِأَصْحَابِهِ فَأَطَالَ الْقِيَامَ حَتَّى جَعَلُوا يَخِرُّونَ ثُمَّ رَكَعَ فَأَطَالَ ثُمَّ رَفَعَ فَأَطَالَ ثُمَّ رَكَعَ فَأَطَالَ ثُمَّ رَفَعَ فَأَطَالَ ثُمَّ سَجَدَ سَجْدَتَيْنِ ثُمَّ قَامَ فَصَنَعَ نَحْوًا مِنْ ذَلِكَ فَكَانَ أَرْبَعَ رَكَعَاتٍ وَأَرْبَعَ سَجَدَاتٍ ‏.‏ وَسَاقَ الْحَدِيثَ ‏.‏\hadithno{1179}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih Muslim (904)}\hadithtrans{Narrated Jabir:There was an eclipse of the sun in the time of the Messenger of Allah (ﷺ) on a hot day. The Messenger of Allah (ﷺ)led his Companions in prayer and prolonged the standing until the people began to fall down. He then bowed and prolonged it; then he raised his head and prolonged (the stay); then he bowed and prolonged it; then he raised his head and prolonged (the stay); then he made two prostrations and then stood up; then he did in the same manner. He thus performed four bowings and four prostrations. Then the narrator narrated the rest of the tradition}}
\hadithdefcmd{abudawud}{1180}{حَدَّثَنَا ابْنُ السَّرْحِ، أَخْبَرَنَا ابْنُ وَهْبٍ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ سَلَمَةَ الْمُرَادِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم قَالَتْ خُسِفَتِ الشَّمْسُ فِي حَيَاةِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَخَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى الْمَسْجِدِ فَقَامَ فَكَبَّرَ وَصَفَّ النَّاسُ وَرَاءَهُ فَاقْتَرَأَ رَسُولُ اللَّهِ صلى الله عليه وسلم قِرَاءَةً طَوِيلَةً ثُمَّ كَبَّرَ فَرَكَعَ رُكُوعًا طَوِيلاً ثُمَّ رَفَعَ رَأْسَهُ فَقَالَ ‏"‏ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ رَبَّنَا وَلَكَ الْحَمْدُ ‏"‏ ‏.‏ ثُمَّ قَامَ فَاقْتَرَأَ قِرَاءَةً طَوِيلَةً هِيَ أَدْنَى مِنَ الْقِرَاءَةِ الأُولَى ثُمَّ كَبَّرَ فَرَكَعَ رُكُوعًا طَوِيلاً هُوَ أَدْنَى مِنَ الرُّكُوعِ الأَوَّلِ ثُمَّ قَالَ ‏"‏ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ رَبَّنَا وَلَكَ الْحَمْدُ ‏"‏ ‏.‏ ثُمَّ فَعَلَ فِي الرَّكْعَةِ الأُخْرَى مِثْلَ ذَلِكَ فَاسْتَكْمَلَ أَرْبَعَ رَكَعَاتٍ وَأَرْبَعَ سَجَدَاتٍ وَانْجَلَتِ الشَّمْسُ قَبْلَ أَنْ يَنْصَرِفَ ‏.‏\hadithno{1180}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1046) Sahih Muslim (901)}\hadithtrans{Narrated A'ishah (May Allah be pleased with her):There was an eclipse of the sun during the lifetime of the Messenger of Allah (ﷺ)came tot he mosque; he stood up and uttered the takbir (Allah is great); the people stood in rows behind him; the Messenger of Allah (ﷺ) recited from the Quran for a long time; then he uttered the takbir (Allah is most great) and performed bowing for a long time, then he raised his head and said: Allah listens to him who praises Him; our Lord, and to Thee be praise; then he stood up and recited from the Qur'an for a long time, but it was less than the first (recitation); he then bowed for a long time, but it was less than the first bowing; he then said, Allah listens to him who praises Him; our Lord, and to Thee be praise. he then did so in the second rak'ah. he thus completed four bowings and four prostrations. The sun had become bright before he departed}}
\hadithdefcmd{abudawud}{1181}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا عَنْبَسَةُ، حَدَّثَنَا يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ كَانَ كَثِيرُ بْنُ عَبَّاسٍ يُحَدِّثُ أَنَّ عَبْدَ اللَّهِ بْنَ عَبَّاسٍ، كَانَ يُحَدِّثُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم صَلَّى فِي كُسُوفِ الشَّمْسِ مِثْلَ حَدِيثِ عُرْوَةَ عَنْ عَائِشَةَ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ صَلَّى رَكْعَتَيْنِ فِي كُلِّ رَكْعَةٍ رَكْعَتَيْنِ ‏.‏\hadithno{1181}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1046) Sahih Muslim (902)}\hadithtrans{Narrated Abd Allah b. 'Abbas:The Messenger of Allah (ﷺ) prayed at the solar eclipse as reported in the tradition narrated by 'Urwah from Aishah from the Messenger of Allah (ﷺ) that he offered two rak'ahs of prayer bowing twice in each rak'ah}}
\hadithdefcmd{abudawud}{1182}{حَدَّثَنَا أَحْمَدُ بْنُ الْفُرَاتِ بْنِ خَالِدٍ أَبُو مَسْعُودٍ الرَّازِيُّ، أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ أَبِي جَعْفَرٍ الرَّازِيُّ، عَنْ أَبِيهِ، عَنْ أَبِي جَعْفَرٍ الرَّازِيِّ، قَالَ أَبُو دَاوُدَ وَحُدِّثْتُ عَنْ عُمَرَ بْنِ شَقِيقٍ، حَدَّثَنَا أَبُو جَعْفَرٍ الرَّازِيُّ، - وَهَذَا لَفْظُهُ وَهُوَ أَتَمُّ - عَنِ الرَّبِيعِ بْنِ أَنَسٍ، عَنْ أَبِي الْعَالِيَةِ، عَنْ أُبَىِّ بْنِ كَعْبٍ، قَالَ انْكَسَفَتِ الشَّمْسُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَإِنَّ النَّبِيَّ صلى الله عليه وسلم صَلَّى بِهِمْ فَقَرَأَ بِسُورَةٍ مِنَ الطُّوَلِ وَرَكَعَ خَمْسَ رَكَعَاتٍ وَسَجَدَ سَجْدَتَيْنِ ثُمَّ قَامَ الثَّانِيَةَ فَقَرَأَ سُورَةً مِنَ الطُّوَلِ وَرَكَعَ خَمْسَ رَكَعَاتٍ وَسَجَدَ سَجْدَتَيْنِ ثُمَّ جَلَسَ كَمَا هُوَ مُسْتَقْبِلَ الْقِبْلَةِ يَدْعُو حَتَّى انْجَلَى كُسُوفُهَا ‏.‏\hadithno{1182}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ubayy b. Ka'b:An eclipse of the sun took place in the time of the Messenger of Allah (ﷺ). The Prophet (ﷺ) led them in prayer. He recited one of the long surahs, bowing five times and prostrating himself twice. He then stood up for the second rak'ah, recited one of the long surahs, bowed five times, prostrated himself twice, then sat where he was facing the qiblah and made the supplication till the eclipse was over}}
\hadithdefcmd{abudawud}{1183}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ سُفْيَانَ، حَدَّثَنَا حَبِيبُ بْنُ أَبِي ثَابِتٍ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ صَلَّى فِي كُسُوفِ الشَّمْسِ فَقَرَأَ ثُمَّ رَكَعَ ثُمَّ قَرَأَ ثُمَّ رَكَعَ ثُمَّ قَرَأَ ثُمَّ رَكَعَ ثُمَّ قَرَأَ ثُمَّ رَكَعَ ثُمَّ سَجَدَ وَالأُخْرَى مِثْلُهَا ‏.‏\hadithno{1183}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Munkar; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih Muslim (909)}\hadithtrans{Narrated Ibn 'Abbas:The Prophet (ﷺ) prayed at solar eclipse; he recited from the Qur'an and then bowed; then he recited from the Qur'an and then bowed; he then recited from the Qur'an and bowed; he then recited fromt eh Qur'an and bowed. Then he prostrated himself and performed the second rak'ah similar to the first}}
\hadithdefcmd{abudawud}{1184}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا الأَسْوَدُ بْنُ قَيْسٍ، حَدَّثَنِي ثَعْلَبَةُ بْنُ عِبَادٍ الْعَبْدِيُّ، مِنْ أَهْلِ الْبَصْرَةِ أَنَّهُ شَهِدَ خُطْبَةً يَوْمًا لِسَمُرَةَ بْنِ جُنْدُبٍ قَالَ قَالَ سَمُرَةُ بَيْنَمَا أَنَا وَغُلاَمٌ مِنَ الأَنْصَارِ نَرْمِي غَرَضَيْنِ لَنَا حَتَّى إِذَا كَانَتِ الشَّمْسُ قِيدَ رُمْحَيْنِ أَوْ ثَلاَثَةٍ فِي عَيْنِ النَّاظِرِ مِنَ الأُفُقِ اسْوَدَّتْ حَتَّى آضَتْ كَأَنَّهَا تَنُّومَةٌ فَقَالَ أَحَدُنَا لِصَاحِبِهِ انْطَلِقْ بِنَا إِلَى الْمَسْجِدِ فَوَاللَّهِ لَيُحْدِثَنَّ شَأْنُ هَذِهِ الشَّمْسِ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فِي أُمَّتِهِ حَدَثًا قَالَ فَدَفَعْنَا فَإِذَا هُوَ بَارِزٌ فَاسْتَقْدَمَ فَصَلَّى فَقَامَ بِنَا كَأَطْوَلِ مَا قَامَ بِنَا فِي صَلاَةٍ قَطُّ لاَ نَسْمَعُ لَهُ صَوْتًا قَالَ ثُمَّ رَكَعَ بِنَا كَأَطْوَلِ مَا رَكَعَ بِنَا فِي صَلاَةٍ قَطُّ لاَ نَسْمَعُ لَهُ صَوْتًا ثُمَّ سَجَدَ بِنَا كَأَطْوَلِ مَا سَجَدَ بِنَا فِي صَلاَةٍ قَطُّ لاَ نَسْمَعُ لَهُ صَوْتًا ‏.‏ ثُمَّ فَعَلَ فِي الرَّكْعَةِ الأُخْرَى مِثْلَ ذَلِكَ قَالَ فَوَافَقَ تَجَلِّي الشَّمْسِ جُلُوسَهُ فِي الرَّكْعَةِ الثَّانِيَةِ قَالَ ثُمَّ سَلَّمَ ثُمَّ قَامَ فَحَمِدَ اللَّهَ وَأَثْنَى عَلَيْهِ وَشَهِدَ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَشَهِدَ أَنَّهُ عَبْدُهُ وَرَسُولُهُ ثُمَّ سَاقَ أَحْمَدُ بْنُ يُونُسَ خُطْبَةَ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{1184}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Samurah ibn Jundub: When, a boy from the Ansar and I were shooting (arrows) towards two of our targets, the sun was sighted by the people at the height of two or three lances above the horizon. It became black like the black herb called tannumah. One of us said to his companion: Let us go to the mosque; by Allah, this incident of the sun will surely bring something new in the community of the Messenger of Allah (ﷺ). As we reached it, we suddenly saw that he (the Prophet) had already come out (of his house). He stepped forward for a long time as much as he could do so in the prayer. But we did not hear his voice. He then performed a bowing and prolonged it as much as he could do in the prayer. But we did not hear his voice. He then prostrated himself with us and prolonged it which he never did in the prayer before. But we did not hear his voice. He then did similarly in the second rak'ah. The sun became bright when he sat after the second rak'ah. Then he uttered the salutation. He then stood up, praised Allah, and extolled Him, and testified that there was no god but Allah and testified that he was His servant and apostle. Ahmad ibn Yunus then narrated the address of the Prophet (ﷺ)}}
\hadithdefcmd{abudawud}{1185}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا أَيُّوبُ، عَنْ أَبِي قِلاَبَةَ، عَنْ قَبِيصَةَ الْهِلاَلِيِّ، قَالَ كُسِفَتِ الشَّمْسُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَخَرَجَ فَزِعًا يَجُرُّ ثَوْبَهُ وَأَنَا مَعَهُ يَوْمَئِذٍ بِالْمَدِينَةِ فَصَلَّى رَكْعَتَيْنِ فَأَطَالَ فِيهِمَا الْقِيَامَ ثُمَّ انْصَرَفَ وَانْجَلَتْ فَقَالَ ‏ "‏ إِنَّمَا هَذِهِ الآيَاتُ يُخَوِّفُ اللَّهُ بِهَا فَإِذَا رَأَيْتُمُوهَا فَصَلُّوا كَأَحْدَثِ صَلاَةٍ صَلَّيْتُمُوهَا مِنَ الْمَكْتُوبَةِ ‏"‏ ‏.‏\hadithno{1185}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Qabisah al-Hilali: There was an eclipse of the sun in the time of the Messenger of Allah (ﷺ). He came out bewildered pulling his garment, and I was in his company at Medina. He prayed two rak'ahs and stood for a long time in them. He then departed and the sun became bright. He then said: There are the signs by means of which Allah, the Exalted, produces dread (in His servants). When you see anything of this nature, then pray as you are praying a fresh obligatory prayer}}
\hadithdefcmd{abudawud}{1186}{حَدَّثَنَا أَحْمَدُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا رَيْحَانُ بْنُ سَعِيدٍ، حَدَّثَنَا عَبَّادُ بْنُ مَنْصُورٍ، عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، عَنْ هِلاَلِ بْنِ عَامِرٍ، أَنَّ قَبِيصَةَ الْهِلاَلِيَّ، حَدَّثَهُ أَنَّ الشَّمْسَ كُسِفَتْ بِمَعْنَى حَدِيثِ مُوسَى قَالَ حَتَّى بَدَتِ النُّجُومُ ‏.‏\hadithno{1186}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Qabisah al Hilali:The solar eclipse took place... The narrator then narrated the tradition like that of Musa. The narrator again said: Until the stars appear (in the heaven)}}
\hadithdefcmd{abudawud}{1187}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ سَعْدٍ، حَدَّثَنَا عَمِّي، حَدَّثَنَا أَبِي، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، حَدَّثَنِي هِشَامُ بْنُ عُرْوَةَ، وَعَبْدُ اللَّهِ بْنُ أَبِي سَلَمَةَ، وَسُلَيْمَانُ بْنُ يَسَارٍ، كُلُّهُمْ قَدْ حَدَّثَنِي عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ كُسِفَتِ الشَّمْسُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَخَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَصَلَّى بِالنَّاسِ فَقَامَ فَحَزَرْتُ قِرَاءَتَهُ فَرَأَيْتُ أَنَّهُ قَرَأَ بِسُورَةِ الْبَقَرَةِ - وَسَاقَ الْحَدِيثَ - ثُمَّ سَجَدَ سَجْدَتَيْنِ ثُمَّ قَامَ فَأَطَالَ الْقِرَاءَةَ فَحَزَرْتُ قِرَاءَتَهُ فَرَأَيْتُ أَنَّهُ قَرَأَ بِسُورَةِ آلِ عِمْرَانَ ‏.‏\hadithno{1187}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Aishah:There was an eclipse of the sun in the time of the Messenger of Allah (ﷺ). The Messenger of Allah (ﷺ) came out and led the people in prayer. he stood up and I guessed that he recited Surah al-Baqarah. The narrator then further transmitted the tradition. He (the Prophet) then prostrated himself twice, and then stood up and prolonged the recitation. then I guessed his recitation and knew that he recited Surah Al-i-Imran}}
\hadithdefcmd{abudawud}{1188}{حَدَّثَنَا الْعَبَّاسُ بْنُ الْوَلِيدِ بْنِ مَزْيَدٍ، أَخْبَرَنِي أَبِي، حَدَّثَنَا الأَوْزَاعِيُّ، أَخْبَرَنِي الزُّهْرِيُّ، أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَرَأَ قِرَاءَةً طَوِيلَةً فَجَهَرَ بِهَا يَعْنِي فِي صَلاَةِ الْكُسُوفِ ‏.‏\hadithno{1188}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated A'ishah (May Allah be pleased with her):The Messenger of Allah (may peace be upon on him) recited from teh Qur'an in a loud voice in the prayer at an eclipse}}
\hadithdefcmd{abudawud}{1189}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي هُرَيْرَةَ، - كَذَا عِنْدَ الْقَاضِي وَالصَّوَابُ عَنِ ابْنِ عَبَّاسٍ، - قَالَ خُسِفَتِ الشَّمْسُ فَصَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم وَالنَّاسُ مَعَهُ فَقَامَ قِيَامًا طَوِيلاً بِنَحْوٍ مِنْ سُورَةِ الْبَقَرَةِ ثُمَّ رَكَعَ وَسَاقَ الْحَدِيثَ ‏.‏\hadithno{1189}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1052) Sahih Muslim (907)}\hadithtrans{Narrated Ibn 'Abbas:An eclipse of the sun took place. the Messenger of Allah (ﷺ) prayed along with the people. He stood up for a long time nearly equal to the recitation of Surah al Baqarah. H then bowed. The narrator then transmitted the rest of the tradition}}
\hadithdefcmd{abudawud}{1190}{حَدَّثَنَا عَمْرُو بْنُ عُثْمَانَ، حَدَّثَنَا الْوَلِيدُ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ نَمِرٍ، أَنَّهُ سَأَلَ الزُّهْرِيَّ فَقَالَ الزُّهْرِيُّ أَخْبَرَنِي عُرْوَةُ، عَنْ عَائِشَةَ، قَالَتْ كُسِفَتِ الشَّمْسُ فَأَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم رَجُلاً فَنَادَى أَنَّ الصَّلاَةَ جَامِعَةٌ ‏.‏\hadithno{1190}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1066) Sahih Muslim (901)}\hadithtrans{Narrated A'ishah (May Allah be pleased with her):There was an eclipse of the sun. The Messenger of Allah (ﷺ) commanded a man who summoned: "The prayer will be held in congregation}}
\hadithdefcmd{abudawud}{1191}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ الشَّمْسُ وَالْقَمَرُ لاَ يُخْسَفَانِ لِمَوْتِ أَحَدٍ وَلاَ لِحَيَاتِهِ فَإِذَا رَأَيْتُمْ ذَلِكَ فَادْعُوا اللَّهَ عَزَّ وَجَلَّ وَكَبِّرُوا وَتَصَدَّقُوا ‏"‏ ‏.‏\hadithno{1191}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1044) Sahih Muslim (901)}\hadithtrans{Narrated A'ishah (May Allah be pleased with her):The sun and the moon are not eclipsed on account of anyone's death or on account of anyone's birth. So when you see that, supplicate Allah, declare His greatness, and give alms}}
\hadithdefcmd{abudawud}{1192}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا مُعَاوِيَةُ بْنُ عَمْرٍو، حَدَّثَنَا زَائِدَةُ، عَنْ هِشَامٍ، عَنْ فَاطِمَةَ، عَنْ أَسْمَاءَ، قَالَتْ كَانَ النَّبِيُّ صلى الله عليه وسلم يَأْمُرُ بِالْعَتَاقَةِ فِي صَلاَةِ الْكُسُوفِ ‏.‏\hadithno{1192}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2519)}\hadithtrans{Narrated Asma:The Prophet (peace be upon him) used to command us to free slaves on the occasion of an eclipse}}
\hadithdefcmd{abudawud}{1193}{حَدَّثَنَا أَحْمَدُ بْنُ أَبِي شُعَيْبٍ الْحَرَّانِيُّ، حَدَّثَنِي الْحَارِثُ بْنُ عُمَيْرٍ الْبَصْرِيُّ، عَنْ أَيُّوبَ السَّخْتِيَانِيِّ، عَنْ أَبِي قِلاَبَةَ، عَنِ النُّعْمَانِ بْنِ بَشِيرٍ، قَالَ كُسِفَتِ الشَّمْسُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَجَعَلَ يُصَلِّي رَكْعَتَيْنِ رَكْعَتَيْنِ وَيَسْأَلُ عَنْهَا حَتَّى انْجَلَتْ ‏.‏\hadithno{1193}\hadithgrade{Al-Albani: Munkar; Muhammad Muhyi Al-Din Abdul Hamid: Munkar; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated An-Nu'man ibn Bashir: There was an eclipse of the sun in the time of the Prophet (ﷺ). He began to pray a series of pairs of rak'ahs enquiring about the sun (at the end of them) till it became clear}}
\hadithdefcmd{abudawud}{1194}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ عَطَاءِ بْنِ السَّائِبِ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ انْكَسَفَتِ الشَّمْسُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَلَمْ يَكَدْ يَرْكَعُ ثُمَّ رَكَعَ فَلَمْ يَكَدْ يَرْفَعُ ثُمَّ رَفَعَ فَلَمْ يَكَدْ يَسْجُدُ ثُمَّ سَجَدَ فَلَمْ يَكَدْ يَرْفَعُ ثُمَّ رَفَعَ فَلَمْ يَكَدْ يَسْجُدُ ثُمَّ سَجَدَ فَلَمْ يَكَدْ يَرْفَعُ ثُمَّ رَفَعَ وَفَعَلَ فِي الرَّكْعَةِ الأُخْرَى مِثْلَ ذَلِكَ ثُمَّ نَفَخَ فِي آخِرِ سُجُودِهِ فَقَالَ ‏"‏ أُفْ أُفْ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ رَبِّ أَلَمْ تَعِدْنِي أَنْ لاَ تُعَذِّبَهُمْ وَأَنَا فِيهِمْ أَلَمْ تَعِدْنِي أَنْ لاَ تُعَذِّبَهُمْ وَهُمْ يَسْتَغْفِرُونَ ‏"‏ ‏.‏ فَفَرَغَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ صَلاَتِهِ وَقَدْ أَمْحَصَتِ الشَّمْسُ وَسَاقَ الْحَدِيثَ ‏.‏\hadithno{1194}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Amr ibn al-'As: There was an eclipse of the sun in the time of the Messenger of Allah (ﷺ). The Messenger of Allah (ﷺ) stood up and he was not going to perform bowing till he bowed; and he was not going to raise his head till he raised (after bowing); and he was not going to prostrate himself till he prostrated himself; and he was not going to raise his head till he raised (at the end of prostration); he did similarly in the second rak'ah, he then puffed in the last prostration saying; Fie, Fie! He then said: My Lord, didst Thou not promise me that Thou wouldst not punish them so long as I will remain among them? Didst Thou not promise me that Thou will not punish them so long as they continue to beg pardon of Thee. The Messenger of Allah (ﷺ) finished the prayer, and the sun was clear. The narrator then narrated the tradition (in full)}}
\hadithdefcmd{abudawud}{1195}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، حَدَّثَنَا الْجُرَيْرِيُّ، عَنْ حَيَّانَ بْنِ عُمَيْرٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ سَمُرَةَ، قَالَ بَيْنَمَا أَنَا أَتَرَمَّى، بِأَسْهُمٍ فِي حَيَاةِ رَسُولِ اللَّهِ صلى الله عليه وسلم إِذْ كُسِفَتِ الشَّمْسُ فَنَبَذْتُهُنَّ وَقُلْتُ لأَنْظُرَنَّ مَا أُحْدِثَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فِي كُسُوفِ الشَّمْسِ الْيَوْمَ فَانْتَهَيْتُ إِلَيْهِ وَهُوَ رَافِعٌ يَدَيْهِ يُسَبِّحُ وَيُحَمِّدُ وَيُهَلِّلُ وَيَدْعُو حَتَّى حُسِرَ عَنِ الشَّمْسِ فَقَرَأَ بِسُورَتَيْنِ وَرَكَعَ رَكْعَتَيْنِ ‏.‏\hadithno{1195}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (913)}\hadithtrans{Narrated 'Abd al-Rahman b. Samurah :During the lifetime of the Messenger of Allah (peace be upon him) I was shooting some arrows when an eclipse of the sun tok place. I, therefore , threw them (the arrows) away and said: I must see how the Messenger of Allah (ﷺ) acts in a solar eclipse today. So I came to him; he was standing (in prayer) raising his hands, glorifying Allah, praising Him, acknowledging that He is the only Deity, and making supplication till the sun was clear. He then recited two surahs and prayed two rak'ahs}}
\hadithdefcmd{abudawud}{1196}{حَدَّثَنَا مُحَمَّدُ بْنُ عَمْرِو بْنِ جَبَلَةَ بْنِ أَبِي رَوَّادٍ، حَدَّثَنِي حَرَمِيُّ بْنُ عُمَارَةَ، عَنْ عُبَيْدِ اللَّهِ بْنِ النَّضْرِ، حَدَّثَنِي أَبِي قَالَ، كَانَتْ ظُلْمَةٌ عَلَى عَهْدِ أَنَسِ بْنِ مَالِكٍ - قَالَ - فَأَتَيْتُ أَنَسًا فَقُلْتُ يَا أَبَا حَمْزَةَ هَلْ كَانَ يُصِيبُكُمْ مِثْلُ هَذَا عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ مَعَاذَ اللَّهِ إِنْ كَانَتِ الرِّيحُ لَتَشْتَدُّ فَنُبَادِرُ الْمَسْجِدَ مَخَافَةَ الْقِيَامَةِ ‏.‏\hadithno{1196}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Anas ibn Malik: Ubaydullah ibn an-Nadr reported on the authority of his father: Darkness prevailed in the time of Anas ibn Malik, I came to Anas and said (to him): AbuHamzah, did anything like this happen to you in the time of the Messenger of Allah (ﷺ)? He replied: Take refuge in Allah. If the wind blew violently, we would run quickly towards the mosque for fear of the coming of the Day of Judgment}}
\hadithdefcmd{abudawud}{1197}{حَدَّثَنَا مُحَمَّدُ بْنُ عُثْمَانَ بْنِ أَبِي صَفْوَانَ الثَّقَفِيُّ، حَدَّثَنَا يَحْيَى بْنُ كَثِيرٍ، حَدَّثَنَا سَلْمُ بْنُ جَعْفَرٍ، عَنِ الْحَكَمِ بْنِ أَبَانَ، عَنْ عِكْرِمَةَ، قَالَ قِيلَ لاِبْنِ عَبَّاسٍ مَاتَتْ فُلاَنَةُ بَعْضُ أَزْوَاجِ النَّبِيِّ صلى الله عليه وسلم فَخَرَّ سَاجِدًا فَقِيلَ لَهُ أَتَسْجُدُ هَذِهِ السَّاعَةَ فَقَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا رَأَيْتُمْ آيَةً فَاسْجُدُوا ‏"‏ ‏.‏ وَأَىُّ آيَةٍ أَعْظَمُ مِنْ ذَهَابِ أَزْوَاجِ النَّبِيِّ صلى الله عليه وسلم\hadithno{1197}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Ikrimah said:Ibn Abbas was informed that so-and-so, a certain wife of the Prophet (ﷺ), had died. He fell down prostrating himself. He was questioned: Why do you prostrate yourself this moment? He said: The Messenger of Allah (ﷺ) said: When you see a portent (an accident), prostrate yourselves. And which portent (accident) can be greater than the death of a wife of the Prophet (ﷺ)}}
